#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-1gKP8M06XQmBx40YvdgzF7
key:                  hls-test-utils-2.3.0.0-1gKP8M06XQmBx40YvdgzF7
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6ec4a192d8cad4ec2bf46c9ac35aec2a
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-1gKP8M06XQmBx40YvdgzF7
depends:
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    async-2.2.6-IB55pRMOICm7lPJ05sVN9d base-4.18.2.1
    blaze-markup-0.8.3.0-En1LhSl79346pvouIeUq7J bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 extra-1.7.16-1gq06OiTdkG7AFSCXWttYR
    filepath-1.4.300.1 ghcide-2.3.0.0-Ik0ryRnzAkjLLtdRv2NXeJ
    hls-graph-2.3.0.0-40a4bM1Ee9D7l9BIGhFTS
    hls-plugin-api-2.3.0.0-8Co8J5z09Yj7X5mYCRuc6W
    lens-5.3.4-6xqoTm4kiuC8ULAJ3RTBph
    lsp-2.2.0.0-G42MvkI8UUDFwGwofUskp3
    lsp-test-0.16.0.0-9kxLNuaHyjcGumNE22VkI
    lsp-types-2.0.2.0-LmHG0NjoDNe4jC9nPopLX6
    row-types-1.0.1.2-ImFsHUkJrRkHT2QtgIv6bk
    tasty-1.5.2-9tyUPHiwq7fIOac17jBCXg
    tasty-expected-failure-0.12.3-G7m60toNfW0J5osSBBELB5
    tasty-golden-2.3.6-1noq2tavYuAA4TUNbPUs1K
    tasty-hunit-0.10.2-1aQPJGmKmQL6O8wlcWrT0t
    tasty-rerun-1.1.20-Ct13Vi7BhrLLpNWRZ3aqu2
    temporary-1.3-2scYfc6PuLr90QcileTdw7 text-2.0.2
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

